@@ -58,7 +58,7 @@ sys.meta_path.insert(0, VTKMetaHook())
 
 def _windows_dll_path():
     import os
-    _vtk_python_path = 'lib/python3.13/site-packages/vtkmodules'
+    _vtk_python_path = 'lib/python3.11/site-packages/vtkmodules'
     _vtk_dll_path = 'bin'
     # Compute the DLL path based on the location of the file and traversing up
     # the installation prefix to append the DLL path.
@@ -110,162 +110,107 @@ def _load_vtkmodules_static():
 # list the contents
 __all__ = [
         'vtkCommonCore',
-    'vtkWebCore',
     'vtkCommonMath',
     'vtkCommonTransforms',
     'vtkCommonDataModel',
     'vtkCommonExecutionModel',
-    'vtkIOCore',
-    'vtkImagingCore',
-    'vtkIOImage',
-    'vtkIOXMLParser',
-    'vtkIOXML',
     'vtkCommonMisc',
     'vtkFiltersCore',
     'vtkRenderingCore',
+    'vtkInteractionStyle',
     'vtkRenderingContext2D',
-    'vtkRenderingFreeType',
-    'vtkRenderingSceneGraph',
-    'vtkRenderingVtkJS',
-    'vtkIOExport',
-    'vtkWebGLExporter',
     'vtkFiltersGeneral',
-    'vtkRenderingHyperTreeGrid',
-    'vtkRenderingUI',
-    'vtkRenderingOpenGL2',
     'vtkFiltersSources',
     'vtkInteractionWidgets',
     'vtkViewsCore',
-    'vtkInteractionStyle',
     'vtkViewsInfovis',
-    'vtkCommonComputationalGeometry',
-    'vtkCommonSystem',
-    'vtkFiltersCellGrid',
-    'vtkIOCellGrid',
-    'vtkIOLegacy',
-    'vtkDomainsChemistry',
-    'vtkRenderingContextOpenGL2',
-    'vtkRenderingVolume',
-    'vtkImagingMath',
-    'vtkRenderingVolumeOpenGL2',
+    'vtkCommonColor',
     'vtkViewsContext2D',
+    'vtkImagingCore',
     'vtkImagingColor',
+    'vtkIOXMLParser',
+    'vtkIOXML',
     'vtkTestingRendering',
-    'vtkInteractionImage',
-    'vtkRenderingRayTracing',
-    'vtkRenderingVolumeAMR',
-    'vtkRenderingLabel',
-    'vtkRenderingQt',
     'vtkPythonContext2D',
-    'vtkParallelCore',
-    'vtkParallelMPI',
-    'vtkRenderingLICOpenGL2',
-    'vtkRenderingParallelLIC',
-    'vtkRenderingParallel',
-    'vtkRenderingVRModels',
-    'vtkRenderingVR',
-    'vtkRenderingOpenXR',
-    'vtkRenderingOpenVR',
-    'vtkRenderingMatplotlib',
+    'vtkRenderingFreeType',
+    'vtkRenderingLabel',
     'vtkRenderingLOD',
+    'vtkIOImage',
+    'vtkRenderingHyperTreeGrid',
+    'vtkRenderingUI',
+    'vtkRenderingOpenGL2',
+    'vtkRenderingLICOpenGL2',
     'vtkRenderingImage',
     'vtkChartsCore',
     'vtkRenderingGridAxes',
-    'vtkIOMovie',
-    'vtkIOVideo',
-    'vtkIOFFMPEG',
-    'vtkRenderingFFMPEGOpenGL2',
-    'vtkRenderingExternal',
+    'vtkRenderingContextOpenGL2',
+    'vtkFiltersCellGrid',
     'vtkRenderingCellGrid',
-    'vtkRenderingAnari',
-    'vtkParallelMPI4Py',
-    'vtkIOXdmf2',
+    'vtkImagingMath',
+    'vtkRenderingVolume',
+    'vtkRenderingVolumeOpenGL2',
     'vtkIOVeraOut',
-    'vtkIOVPIC',
     'vtkIOTecplotTable',
-    'vtkIOTRUCHAS',
     'vtkIOSegY',
-    'vtkIOSQL',
-    'vtkIOPostgreSQL',
-    'vtkIOXdmf3',
-    'vtkIOParallelXdmf3',
     'vtkIOParallelXML',
-    'vtkIONetCDF',
-    'vtkIOParallelNetCDF',
-    'vtkIOLSDyna',
-    'vtkIOParallelLSDyna',
-    'vtkIOExodus',
-    'vtkIOParallelExodus',
+    'vtkIOCore',
     'vtkIOPLY',
-    'vtkIOPIO',
-    'vtkIOPDAL',
-    'vtkIOOpenVDB',
+    'vtkIOMovie',
     'vtkIOOggTheora',
-    'vtkIOOMF',
-    'vtkIOODBC',
-    'vtkIOOCCT',
-    'vtkIOMySQL',
+    'vtkIONetCDF',
     'vtkIOMotionFX',
+    'vtkIOCellGrid',
+    'vtkIOLegacy',
     'vtkIOGeometry',
     'vtkIOParallel',
-    'vtkIOMPIParallel',
-    'vtkIOMPIImage',
     'vtkIOMINC',
-    'vtkIOLAS',
+    'vtkIOLSDyna',
     'vtkIOLANLX3D',
     'vtkIOImport',
+    'vtkParallelCore',
     'vtkIOIOSS',
     'vtkIOHDF',
-    'vtkIOH5part',
-    'vtkIOH5Rage',
-    'vtkIOGeoJSON',
-    'vtkIOFides',
     'vtkIOFLUENTCFF',
+    'vtkIOVideo',
     'vtkIOFDS',
     'vtkIOInfovis',
+    'vtkRenderingSceneGraph',
+    'vtkRenderingVtkJS',
+    'vtkIOExport',
     'vtkIOExportPDF',
     'vtkRenderingGL2PSOpenGL2',
     'vtkIOExportGL2PS',
+    'vtkIOExodus',
     'vtkIOEngys',
     'vtkIOEnSight',
     'vtkIOERF',
     'vtkIOCityGML',
     'vtkIOChemistry',
     'vtkIOCesium3DTiles',
-    'vtkIOCatalystConduit',
     'vtkIOCONVERGECFD',
     'vtkIOCGNSReader',
-    'vtkIOAvmesh',
     'vtkIOAsynchronous',
-    'vtkIOAlembic',
     'vtkIOAMR',
-    'vtkIOADIOS2',
+    'vtkInteractionImage',
     'vtkInfovisLayout',
-    'vtkInfovisBoostGraphAlgorithms',
     'vtkImagingStencil',
     'vtkImagingStatistics',
     'vtkImagingGeneral',
-    'vtkImagingOpenGL2',
     'vtkImagingMorphological',
     'vtkImagingFourier',
+    'vtkIOSQL',
     'vtkRenderingAnnotation',
     'vtkImagingHybrid',
-    'vtkIOGDAL',
-    'vtkGeovisGDAL',
     'vtkGeovisCore',
     'vtkFiltersTopology',
     'vtkFiltersTensor',
     'vtkFiltersSelection',
     'vtkFiltersSMP',
-    'vtkFiltersReebGraph',
     'vtkFiltersPython',
     'vtkFiltersProgrammable',
     'vtkFiltersModeling',
     'vtkFiltersPoints',
-    'vtkFiltersVerdict',
-    'vtkFiltersParallelVerdict',
     'vtkFiltersStatistics',
-    'vtkFiltersParallelStatistics',
     'vtkFiltersImaging',
     'vtkFiltersExtraction',
     'vtkFiltersGeometry',
@@ -274,25 +219,19 @@ __all__ = [
     'vtkFiltersTexture',
     'vtkFiltersParallel',
     'vtkFiltersParallelImaging',
-    'vtkFiltersParallelGeometry',
-    'vtkFiltersFlowPaths',
-    'vtkFiltersParallelFlowPaths',
-    'vtkFiltersParallelDIY2',
     'vtkFiltersTemporal',
     'vtkFiltersGeometryPreview',
     'vtkFiltersGeneric',
+    'vtkCommonComputationalGeometry',
+    'vtkFiltersFlowPaths',
     'vtkFiltersAMR',
-    'vtkDomainsParallelChemistry',
-    'vtkFiltersParallelMPI',
+    'vtkDomainsChemistry',
     'vtkDomainsChemistryOpenGL2',
     'vtkCommonPython',
-    'vtkCommonArchive',
-    'vtkCommonColor',
     'vtkImagingSources',
     'vtkInfovisCore',
-    'vtkAcceleratorsVTKmCore',
-    'vtkAcceleratorsVTKmDataModel',
-    'vtkAcceleratorsVTKmFilters',
+    'vtkCommonSystem',
+    'vtkFiltersVerdict',
     'vtkFiltersReduction',
     'all',
     'gtk',
@@ -306,7 +245,7 @@ __all__ = [
 ]
 #------------------------------------------------------------------------------
 # get the version
-__version__ = "9.5.1"
+__version__ = "9.5.2"
 
 #------------------------------------------------------------------------------
 # describe import dependencies to properly define Python @override
